@@ -1,9 +1,22 @@
+#!/usr/bin/env python3
+# -*- coding: utf-8 -*-
+
+# This file is part of CbM (https://github.com/ec-jrc/cbm).
+# Author    : Gilbert Voican, Konstantinos Anastasakis
+# Credits   : GTCAP Team
+# Copyright : 2021 European Commission, Joint Research Centre
+# License   : 3-Clause BSD
+import os
+
+
 def v1(*args):
+    os.makedirs("foi", exist_ok=True)
     from cbm.foi import foi_v1
     return foi_v1.main(*args)
 
 
 def v2(*args):
+    os.makedirs("foi", exist_ok=True)
     from cbm.foi import foi_v2
     return foi_v2.main(*args)
 
@@ -24,4 +37,5 @@ def import_db_functions():
         if db.db_func_exist(basename(f).split('.')[0]):
             print(f"The '{basename(f)}' Was imported to the database.")
         else:
+            print(f"{path_foi_func}/{basename(f)}")
             print(f"Could not add function '{basename(f)}' to dattabase.")
