@@ -57,7 +57,7 @@ def by_location(aoi, lon, lat, start_date, end_date, band, chipsize,
 
     images_dir = normpath(join(workdir, 'chip_images'))
     get_requests.rcbl(parcel, start_date, end_date, [band],
-                      chipsize, images_dir)
+                      chipsize, images_dir, debug)
 
     images_list = normpath(join(workdir, 'chip_images',
                                 f'images_list.{band}.csv'))
@@ -111,7 +111,7 @@ def by_pid(aoi, year, pid, start_date, end_date, band, chipsize,
         print(f"Getting '{band}' chip images for parcel: {pid}")
 
     get_requests.rcbl(parcel, start_date, end_date, [band],
-                      chipsize, images_dir)
+                      chipsize, images_dir, debug)
 
     images_list = normpath(join(workdir, 'chip_images',
                                 f'images_list.{band}.csv'))
