@@ -12,6 +12,7 @@ from os.path import normpath, join
 from ipywidgets import (Label, VBox, HBox, Dropdown, Button, Layout)
 
 from cbm.utils import config
+from cbm.ipycbm.utils import settings_ds
 from cbm.ipycbm.ipy_ext import ext_func, ext_card2db
 
 
@@ -46,13 +47,13 @@ def extract():
     @db_config.on_click
     def db_config_on_click(b):
         if db_conf_box.children == ():
-            db_conf_box.children = [settings.direct_conn()]
+            db_conf_box.children = [settings_ds.direct_conn()]
         else:
             db_conf_box.children = ()
     wbox = VBox([l_connec, VBox([db_box, db_conf_box]),
                  l_create, ext_func.create_tables(),
                  l_upload, ext_func.upload_shp(path_data),
-                 l_carddb, ext_card2db.dias_cat(),
+                 l_carddb, ext_card2db.main(),
                  l_extrac, ext_func.extraction()])
 
     return wbox
