@@ -53,6 +53,8 @@ def by_location(aoi, year, lon, lat, chipsize=512, extend=512, tms=['google'],
     """
     if type(tms) is str:
         tms = [tms]
+    if len(tms) < columns:
+        columns = len(tms)
 
     try:
         parcel = parcel_info.by_location(aoi, year, lon, lat, ptype,
@@ -72,15 +74,11 @@ def by_location(aoi, year, lon, lat, chipsize=512, extend=512, tms=['google'],
         if debug:
             print("No parcel information found.", err)
 
-    if len(tms) < columns:
-        columns = len(tms)
-
     bg_path = normpath(join(workdir, 'backgrounds'))
 
     same_args = check_args(bg_path, chipsize, extend, debug)
 
     if debug:
-        print('path: ', bg_path)
         print('same args: ', same_args)
         print('aoi-year-lon-lat-chipsize-extend-tms-ptype-columns-debug')
         print(aoi, year, lon, lat, chipsize,
@@ -143,8 +141,7 @@ def by_pid(aoi, year, pid, chipsize=512, extend=512, tms=['google'],
 
     Examples:
         from cbm.view import background
-        background.by_location(aoi, year, lon, lat, 512, 512, 'Google',
-                                True, True)
+        background.by_pid(aoi, year, pid, 512, 512, 'Google', True, True)
 
     Arguments:
         aoi, the area of interest (str)
@@ -156,20 +153,22 @@ def by_pid(aoi, year, pid, chipsize=512, extend=512, tms=['google'],
         columns, the number of columns of the grid
         debug, print or not procedure information (Boolean).
     """
+    workdir = normpath(join(config.get_value(['paths', 'temp']),
+                            aoi, str(year), str(pid)))
+    file_info = normpath(join(workdir, 'info.json'))
+    if not isfile(file_info):
+        if not parcel_info.by_pid(aoi, year, pid, ptype, True, False, debug):
+            return "No parcel found, please check the parcel ID"
 
     if type(tms) is str:
         tms = [tms]
     if len(tms) < columns:
         columns = len(tms)
 
-    workdir = normpath(join(config.get_value(['paths', 'temp']),
-                            aoi, str(year), str(pid)))
     bg_path = normpath(join(workdir, 'backgrounds'))
-
-    same_args = check_args(bg_path, chipsize, extend)
+    same_args = check_args(bg_path, chipsize, extend, debug)
 
     if debug:
-        print('path: ', bg_path)
         print('same args: ', same_args)
         print('aoi, year, pid, chipsize, extend, tms, columns, debug')
         print(aoi, year, pid, chipsize, extend, tms, columns, debug)
@@ -179,7 +178,7 @@ def by_pid(aoi, year, pid, chipsize=512, extend=512, tms=['google'],
             get_bg.by_pid(aoi, year, pid, chipsize,
                           extend, t, ptype, True, debug)
 
-    with open(normpath(join(workdir, 'info.json')), 'r') as f:
+    with open(file_info, 'r') as f:
         parcel = json.load(f)
 
     with rasterio.open(normpath(join(bg_path, f'{tms[0].lower()}.tif'))) as img:
